==> agnostos-0.9.7.tar.gz: agnostos/agnostos_docroot/update_task.pl <==
#!/usr/bin/perl -w

# Copyright (C) 2000 Julian T. J. Midgley <jtjm@xenoclast.org>
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
# A copy of version 2 of the GNU General Public License may be found
# in the file "LICENCE" in the original Agnostos installation driectory.

#--------------------------------------------------------------------------
# audit_prepare($update, $todoid, $status, $userid, $groupid, $depid, $date, $priority, $dbh)
#
# Log changes in status, userid, groupid, depid, date to the audit
# table.  Returns a database query handle to be passed to
# audit_execute() after the update has been made.

sub
audit_prepare
{
    my ($update, $todoid, $status, $userid, $groupid, $depid, $date, $priority, $dbh) = @_;
    my $auditstr = "";
    my ($audit_dbq, %users, %groups, %depts); 

    %users  = fetch_ents( 'user',       $dbh);
    %groups = fetch_ents( 'workgroup',  $dbh);
    %depts  = fetch_ents( 'department', $dbh);

    unless ($update) {
	# We are auditing an 'add'
	$auditstr = "Task created";
	$audit_dbq = $dbh -> prepare ("INSERT INTO audit (todoid, comment, date) 
                                       VALUES ($todoid, '$auditstr', NOW())");
    }
    else {
	# We are auditing an 'update'
	my $dbq = $dbh -> prepare ("SELECT status, userid, groupid, depid, date, priority
                                    FROM todo, assigned
                                    WHERE todo.todoid = assigned.todoid 
                                    AND todo.todoid = $todoid");
	$dbq -> execute;
	my ($old_status, $old_userid, $old_groupid, $old_depid, $old_date, $old_priority) 
	    = $dbq -> fetchrow_array;
	
	# Normalise dates
	if (defined $old_date) {
	    $old_date =~ s/-0/-/g;
	}
	else {
	    $old_date = "";
	}
	$date =~ s/\'//g;

	unless ( $old_status eq $status ) {
	    $auditstr .= "Status changed from $old_status to $status\n";
	}
	unless ( $old_priority == $priority ) {
	    if ( $old_priority < $priority ) {
		$auditstr .= "Priority decreased to $priority from $old_priority\n";
	    }
	    else {
		$auditstr .= "Priority increased to $priority from $old_priority\n";
	    }
	}
	unless ( $old_userid == $userid ) {
	    if ( $old_userid == 1 ) {
		$auditstr .= "Assigned to $users{$userid}\n";
	    }
	    else {
		$auditstr .= "Assigned to $users{$userid} from $users{$old_userid}\n";
	    }
	}
	unless ( $old_groupid == $groupid ) {
	    if ( $old_groupid == 1) {
		$auditstr .= "Assigned to group $groups{$groupid}\n";
	    }
	    else {
		$auditstr .= "Assigned to group $groups{$groupid} from $groups{$old_groupid}\n";
	    }
	}
	unless ( $old_depid == $depid ) {
	    if ( $old_depid == 1 ) {
		$auditstr .= "Assigned to department $depts{$depid}\n";
	    }
	    else {
		$auditstr .= "Assigned to department $depts{$depid} from $depts{$old_depid}\n";
	    }
	}
	unless ( $old_date eq $date ) {
	    unless ($date eq "NULL" && $old_date eq "") {
		if ($old_date eq "") {
		    $auditstr .= "Due date $date assigned\n";
		}
		else {
		    $auditstr .= "Due date changed to $date from $old_date\n";
		}
	    }
	}
	$audit_dbq = $dbh -> prepare ("INSERT INTO audit (todoid, comment, date)
                                       VALUES ($todoid, '$auditstr', NOW())");
    }
    return $audit_dbq;
}

#--------------------------------------------------------------------------
# audit_execute ($audit_dbq) 
# Executes the database query pointed to by $audit_dbq.

sub
audit_execute
{
    my $audit_dbq = shift @_;
    $audit_dbq -> execute;
    $audit_dbq -> finish;
    return;
}

#--------------------------------------------------------------------------
# main
use taskman_lib;
use strict;
use CGI;

my $dbh   = dbserver_connect('agnostos');
my $query = new CGI;
my ($audit_dbq, $dbq);
my $action   = $query -> param('action');
my $todoid   = $query -> param('todoid');
my $title    = $query -> param('title');
my $status   = $query -> param('status');
my $priority = $query -> param('priority');
my $userid   = $query -> param('userid');
my $groupid  = $query -> param('groupid');
my $depid    = $query -> param('depid');
my $desc     = $query -> param('desc');
my $note     = $query -> param('note');
my $day      = $query -> param('day');
my $month    = $query -> param('month');
my $year     = $query -> param('year');
my $nodate   = $query -> param('nodate');
my $insdate;
if ( (defined $nodate)  && ($nodate eq 'true') ) {
    $insdate = 'NULL';
}
else {
    $insdate = "'$year-$month-$day'";
}
$title = sql_quote($title);
$note  = sql_quote($note);
$desc  = sql_quote($desc);

if ($action eq 'update')  {
    $audit_dbq = audit_prepare (1, $todoid, $status, $userid, $groupid, $depid, $insdate, $priority, $dbh);
    $dbq = $dbh -> prepare ("UPDATE todo ".
			    "SET title       = '$title', ".
			    "    status      = '$status', ".
			    "    priority    = $priority, ".
			    "    description = '$desc', ".
			    "    note        = '$note', ".
			    "    date        = $insdate, ".
			    "    completed_date = NOW() ".
			    "WHERE todoid = $todoid");
    $dbq -> execute;
    $dbq -> finish;
    $dbq = $dbh -> prepare ("UPDATE assigned ".
			    "SET userid  = $userid, ".
			    "    groupid = $groupid, ".
			    "    depid   = $depid ".
			    "WHERE todoid = $todoid");
    $dbq -> execute;
    $dbq -> finish;
    audit_execute($audit_dbq);

    print $query -> header();
    print "\n<html><head><head><meta name=\"pragma\" content=\"nocache\">".
          "<meta http-equiv=Refresh content=\"0; URL=view_tasks.pl\">".
	  "<title>Updated Task</title></head><body bgcolor=white>\n";

    print "<h2>Task Updated</h2>";
    print html_footer;

}
else {

    $dbq = $dbh -> prepare ("INSERT INTO todo ".
			    "( title, status, priority, description, note, date ) ".
			    "VALUES ".
			    "( '$title', '$status', $priority, '$desc', '$note', $insdate )");
    $dbq -> execute;
    $todoid = $dbh -> {'mysql_insertid'};
    $dbq -> finish;
    $audit_dbq = audit_prepare (0, $todoid, $status, $userid, $groupid, $depid, $insdate, $priority, $dbh);

    $dbq = $dbh -> prepare ("INSERT INTO assigned ".
			    "( todoid, userid, groupid, depid ) ".
			    "VALUES ".
			    "( $todoid, $userid, $groupid, $depid )");
    $dbq -> execute;
    $dbq -> finish;
    audit_execute($audit_dbq);
    print $query -> header();
    print "\n<html><head><meta name=\"pragma\" content=\"nocache\">".
	  "<meta http-equiv=Refresh content=\"0; URL=view_tasks.pl\">".
	  "<title>Updated Task</title></head><body bgcolor=white>\n";

    print "<h2>Task Added</h2>";
    print html_footer;
}
			    

$dbh -> disconnect;

==> agnostos-0.9.10.tar.gz: agnostos/agnostos_docroot/update_task.pl <==
#!/usr/bin/perl -w

# Copyright (C) 2000 Julian T. J. Midgley <jtjm@xenoclast.org>
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
# A copy of version 2 of the GNU General Public License may be found
# in the file "LICENCE" in the original Agnostos installation driectory.

#--------------------------------------------------------------------------
# audit_prepare($update, $todoid, $status, $userid, $groupid, $depid, $date, $priority, $dbh)
#
# Log changes in status, userid, groupid, depid, date to the audit
# table.  Returns a database query handle to be passed to
# audit_execute() after the update has been made.

sub
audit_prepare
{
    my ($update, $todoid, $status, $userid, $groupid, $depid, $date, $priority, $dbh) = @_;
    my $auditstr = "";
    my ($audit_dbq, %users, %groups, %depts); 

    %users  = fetch_ents( 'user',       $dbh);
    %groups = fetch_ents( 'workgroup',  $dbh);
    %depts  = fetch_ents( 'department', $dbh);

    unless ($update) {
	# We are auditing an 'add'
	$auditstr = "Task created";
	$audit_dbq = $dbh -> prepare ("INSERT INTO audit (todoid, comment, date) 
                                       VALUES ($todoid, '$auditstr', NOW())");
    }
    else {
	# We are auditing an 'update'
	my $dbq = $dbh -> prepare ("SELECT status, userid, groupid, depid, date, priority
                                    FROM todo, assigned
                                    WHERE todo.todoid = assigned.todoid 
                                    AND todo.todoid = $todoid");
	$dbq -> execute;
	my ($old_status, $old_userid, $old_groupid, $old_depid, $old_date, $old_priority) 
	    = $dbq -> fetchrow_array;
	
	# Normalise dates
	if (defined $old_date) {
	    $old_date =~ s/-0/-/g;
	}
	else {
	    $old_date = "";
	}
	$date =~ s/\'//g;

	unless ( $old_status eq $status ) {
	    $auditstr .= "Status changed from $old_status to $status\n";
	}
	unless ( $old_priority == $priority ) {
	    if ( $old_priority < $priority ) {
		$auditstr .= "Priority decreased to $priority from $old_priority\n";
	    }
	    else {
		$auditstr .= "Priority increased to $priority from $old_priority\n";
	    }
	}
	unless ( $old_userid == $userid ) {
	    if ( $old_userid == 1 ) {
		$auditstr .= "Assigned to $users{$userid}\n";
	    }
	    else {
		$auditstr .= "Assigned to $users{$userid} from $users{$old_userid}\n";
	    }
	}
	unless ( $old_groupid == $groupid ) {
	    if ( $old_groupid == 1) {
		$auditstr .= "Assigned to group $groups{$groupid}\n";
	    }
	    else {
		$auditstr .= "Assigned to group $groups{$groupid} from $groups{$old_groupid}\n";
	    }
	}
	unless ( $old_depid == $depid ) {
	    if ( $old_depid == 1 ) {
		$auditstr .= "Assigned to department $depts{$depid}\n";
	    }
	    else {
		$auditstr .= "Assigned to department $depts{$depid} from $depts{$old_depid}\n";
	    }
	}
	unless ( $old_date eq $date ) {
	    unless ($date eq "NULL" && $old_date eq "") {
		if ($old_date eq "") {
		    $auditstr .= "Due date $date assigned\n";
		}
		else {
		    $auditstr .= "Due date changed to $date from $old_date\n";
		}
	    }
	}
	$audit_dbq = $dbh -> prepare ("INSERT INTO audit (todoid, comment, date)
                                       VALUES ($todoid, '$auditstr', NOW())");
    }
    return $audit_dbq;
}

#--------------------------------------------------------------------------
# audit_execute ($audit_dbq) 
# Executes the database query pointed to by $audit_dbq.

sub
audit_execute
{
    my $audit_dbq = shift @_;
    $audit_dbq -> execute;
    $audit_dbq -> finish;
    return;
}

#--------------------------------------------------------------------------
# main
use taskman_lib;
use strict;
use CGI;
use CGI::Carp qw(fatalsToBrowser);

my %config = get_config(); 
my $dbh   = dbserver_connect(\%config);
my $query = new CGI;
my ($audit_dbq, $dbq);
my $action   = $query -> param('action');
my $todoid   = $query -> param('todoid');
my $title    = $query -> param('title');
my $status   = $query -> param('status');
my $priority = $query -> param('priority');
my $userid   = $query -> param('userid');
my $groupid  = $query -> param('groupid');
my $depid    = $query -> param('depid');
my $desc     = $query -> param('desc');
my $note     = $query -> param('note');
my $day      = $query -> param('day');
my $month    = $query -> param('month');
my $year     = $query -> param('year');
my $nodate   = $query -> param('nodate');
my $insdate;
if ( (defined $nodate)  && ($nodate eq 'true') ) {
    $insdate = 'NULL';
}
else {
    $insdate = "'$year-$month-$day'";
}
$title = sql_quote($title);
$note  = sql_quote($note);
$desc  = sql_quote($desc);

if ($action eq 'update')  {
    $audit_dbq = audit_prepare (1, $todoid, $status, $userid, $groupid, $depid, $insdate, $priority, $dbh);
    $dbq = $dbh -> prepare ("UPDATE todo ".
			    "SET title       = '$title', ".
			    "    status      = '$status', ".
			    "    priority    = $priority, ".
			    "    description = '$desc', ".
			    "    note        = '$note', ".
			    "    date        = $insdate, ".
			    "    completed_date = NOW() ".
			    "WHERE todoid = $todoid");
    $dbq -> execute;
    $dbq -> finish;
    $dbq = $dbh -> prepare ("UPDATE assigned ".
			    "SET userid  = $userid, ".
			    "    groupid = $groupid, ".
			    "    depid   = $depid ".
			    "WHERE todoid = $todoid");
    $dbq -> execute;
    $dbq -> finish;
    audit_execute($audit_dbq);

    print $query -> header();
    print "\n<html><head><head><meta name=\"pragma\" content=\"nocache\">".
          "<meta http-equiv=Refresh content=\"0; URL=view_tasks.pl\">".
	  "<title>Updated Task</title></head><body bgcolor=white>\n";

    print "<h2>Task Updated</h2>";
    print html_footer;

}
else {

    $dbq = $dbh -> prepare ("INSERT INTO todo ".
			    "( title, status, priority, description, note, date, completed_date ) ".
			    "VALUES ".
			    "( '$title', '$status', $priority, '$desc', '$note', $insdate, NOW() )");
    $dbq -> execute;
    $todoid = $dbh -> {'mysql_insertid'};
    $dbq -> finish;
    $audit_dbq = audit_prepare (0, $todoid, $status, $userid, $groupid, $depid, $insdate, $priority, $dbh);

    $dbq = $dbh -> prepare ("INSERT INTO assigned ".
			    "( todoid, userid, groupid, depid ) ".
			    "VALUES ".
			    "( $todoid, $userid, $groupid, $depid )");
    $dbq -> execute;
    $dbq -> finish;
    audit_execute($audit_dbq);
    print $query -> header();
    print "\n<html><head><meta name=\"pragma\" content=\"nocache\">".
	  "<meta http-equiv=Refresh content=\"0; URL=view_tasks.pl\">".
	  "<title>Updated Task</title></head><body bgcolor=white>\n";

    print "<h2>Task Added</h2>";
    print html_footer;
}
			    

$dbh -> disconnect;
